Associativity

Enum Associativity 

pub enum Associativity {
    Left,
    Right,
}
The associativity of a binary or unary operation.

Variants



Left

The binary / unary operation is left-associative.

For binary operations, this means a op b op c is evaluated as (a op b) op c. For unary operations, this means a op op is evaluated as (a op) op (the operators appear to the right of the operand).



Right

The binary / unary operation is right-associative.

For binary operations, this means a op b op c is evaluated as a op (b op c). For unary operations, this means op op a is evaluated as op (op a) (the operators appear to the left of the operand).